Crate nylon_ring_host

Crate nylon_ring_host 

Nylon Ring Host - A high-performance plugin host for the nylon-ring ABI.

This crate provides the host-side implementation for loading and managing plugins that conform to the nylon-ring ABI. It supports multiple execution modes including fire-and-forget calls, request-response patterns, and bidirectional streaming.

Structs

Extensions
A type map of protocol extensions.
HostMetrics
Point-in-time host metrics suitable for application monitoring hooks.
LoadedPlugin
A loaded plugin instance.
NrStatus
Status code passed across the Nylon Ring ABI.
NylonRingHost
The main host for loading and managing nylon-ring plugins.
PluginEntry
A pre-resolved plugin entry point that dispatches by integer id : the per-call entry-name comparison and NrStr construction are paid once, in PluginHandle::entry, instead of on every call.
PluginHandle
A handle to a specific plugin for making calls.
ResponseBytes
A unary response as returned by crate::PluginHandle::call_response_bytes.
StreamFrame
A frame in a streaming response.
StreamReceiver
A receiver for streaming responses.

Enums

NylonRingHostError
Errors that can occur in the nylon-ring-host crate.

Constants

DEFAULT_STREAM_CAPACITY
Default number of frames buffered for each response stream.

Type Aliases

Result
Result type alias for this crate.