Nylon Ring Host - A high-performance plugin host for the nylon-ring ABI.
This crate provides the host-side implementation for loading and managing plugins that conform to the nylon-ring ABI. It supports multiple execution modes including fire-and-forget calls, request-response patterns, and bidirectional streaming.
Structs
- Extensions
- A type map of protocol extensions.
- Host
Metrics - Point-in-time host metrics suitable for application monitoring hooks.
- Loaded
Plugin - A loaded plugin instance.
- NrStatus
- Status code passed across the Nylon Ring ABI.
- Nylon
Ring Host - The main host for loading and managing nylon-ring plugins.
- Plugin
Handle - A handle to a specific plugin for making calls.
- Stream
Frame - A frame in a streaming response.
- Stream
Receiver - A receiver for streaming responses.
Enums
- Nylon
Ring Host Error - Errors that can occur in the nylon-ring-host crate.
Constants
- DEFAULT_
STREAM_ CAPACITY - Default number of frames buffered for each response stream.
Type Aliases
- Result
- Result type alias for this crate.